@@ -1,3 +1,4 @@
+{-# LANGUAGE CPP #-}
 {-# LANGUAGE ExistentialQuantification #-}
 {-# LANGUAGE OverloadedStrings #-}
 
@@ -7,7 +8,7 @@
 -- |
 --  Module      :  Datatype
 --  Copyright   :  (c) 2003, Graham Klyne, 2009 Vasili I Galchin,
---                 2011, 2012, 2018 Douglas Burke
+--                 2011, 2012, 2018, 2019 Douglas Burke
 --  License     :  GPL V2
 --
 --  Maintainer  :  Douglas Burke
@@ -71,7 +72,9 @@ import Swish.Utils.ListHelpers (flist)
 --
 -- import Swish.Utils.ShowM (ShowM(..))
 
+#if (!defined(__GLASGOW_HASKELL__)) || (__GLASGOW_HASKELL__ < 808)
 import Control.Applicative ((<$>))
+#endif
 
 import Data.Maybe (isJust, catMaybes)
 
