@@ -1,4 +1,3 @@
-{-# LANGUAGE CPP #-}
 {-# LANGUAGE FlexibleInstances #-}
 {-# LANGUAGE MultiParamTypeClasses #-}
 
@@ -8,12 +7,12 @@
 -- |
 --  Module      :  GraphMatch
 --  Copyright   :  (c) 2003, Graham Klyne, 2009 Vasili I Galchin,
---                 2011, 2012, 2016 Douglas Burke
+--                 2011, 2012, 2016, 2018 Douglas Burke
 --  License     :  GPL V2
 --
 --  Maintainer  :  Douglas Burke
 --  Stability   :  experimental
---  Portability :  CPP, FlexibleInstances, MultiParamTypeClasses
+--  Portability :  FlexibleInstances, MultiParamTypeClasses
 --
 --  This module contains graph-matching logic.
 --
@@ -564,12 +563,7 @@ reclassify gs1 gs2 lmap@(LabelMap _ lm) ecpairs =
 -- Replace the values in lm1 with those from lm2, but do not copy over new
 -- keys from lm2
 classifyCombine :: (Ord a) => M.Map a b -> M.Map a b -> M.Map a b
-#if MIN_VERSION_containers(0,5,0)
 classifyCombine = M.mergeWithKey (\_ _ v -> Just v) id (const M.empty)
-#else
--- rely on the left-biased nature of union
-classifyCombine lm1 lm2 = M.intersection lm2 lm1 `M.union` lm1
-#endif
 
 -- | Calculate a new index value for a supplied set of labels based on the
 --  supplied label map and adjacency calculations in the supplied graph
@@ -677,7 +671,7 @@ graphMapEq lmap = (==) `on` graphMap lmap
 --------------------------------------------------------------------------------
 --
 --  Copyright (c) 2003, Graham Klyne, 2009 Vasili I Galchin,
---    2011, 2012 Douglas Burke
+--    2011, 2012, 2016, 2018 Douglas Burke
 --  All rights reserved.
 --
 --  This file is part of Swish.
