@@ -9,7 +9,7 @@
 -- |
 --  Module      :  Graph
 --  Copyright   :  (c) 2003, Graham Klyne, 2009 Vasili I Galchin,
---                 2011, 2012, 2013, 2014, 2015, 2016 Douglas Burke
+--                 2011, 2012, 2013, 2014, 2015, 2016, 2018 Douglas Burke
 --  License     :  GPL V2
 --
 --  Maintainer  :  Douglas Burke
@@ -221,6 +221,10 @@ import Data.Time (UTCTime, Day, ParseTime, parseTime, formatTime)
 import System.Locale (defaultTimeLocale)  
 #endif
 
+#if !(MIN_VERSION_base(4, 11, 0))
+import Data.Semigroup
+#endif
+
 import Text.Printf
 
 import qualified Data.Map as M
@@ -336,7 +340,7 @@ instance Label RDFLabel where
     getLocal   (Blank loc)  = loc
     getLocal   (Var   loc)  = '?':loc
     getLocal   (Res   sn)   = "Res_" ++ (T.unpack . getLName . getScopeLocal) sn
-    getLocal   (NoNode)     = "None"
+    getLocal   NoNode       = "None"
     getLocal   _            = "Lit_"
 
     makeLabel  ('?':loc)    = Var loc
@@ -403,9 +407,9 @@ class FromRDFLabel a where
 instance ToRDFLabel RDFLabel where
   toRDFLabel = id
   
--- | This is just @Just . id@.  
+-- | This is just @Just@.
 instance FromRDFLabel RDFLabel where
-  fromRDFLabel = Just . id
+  fromRDFLabel = Just
   
 -- TODO: remove this hack when finished conversion to Text
 maybeReadStr :: (Read a) => T.Text -> Maybe a  
@@ -1283,10 +1287,17 @@ instance LDGraph NSGraph lb where
     getArcs      = statements 
     setArcs g as = g { statements=as }
 
--- | The 'mappend' operation uses 'merge' rather than 'addGraphs'.
+-- | The '<>' operation uses 'merge' rather than 'addGraphs'.
+instance (Label lb) => Semigroup (NSGraph lb) where
+    (<>) = merge
+
+-- | The 'mappend' operation uses the Semigroup instance
+--   (so 'merge' rather than 'addGraphs').
 instance (Label lb) => Monoid (NSGraph lb) where
     mempty  = emptyGraph
-    mappend = merge
+#if !(MIN_VERSION_base(4, 11, 0))
+    mappend = (<>)
+#endif
 
 -- fmapNSGraph :: (Ord lb1, Ord lb2) => (lb1 -> lb2) -> NSGraph lb1 -> NSGraph lb2
   
@@ -1608,7 +1619,7 @@ updateRDFGraph gr as = gr { statements=as }
 --------------------------------------------------------------------------------
 --
 --  Copyright (c) 2003, Graham Klyne, 2009 Vasili I Galchin,
---    2011, 2012, 2013, 2014 Douglas Burke
+--    2011, 2012, 2013, 2014, 2015, 2016, 2018 Douglas Burke
 --  All rights reserved.
 --
 --  This file is part of Swish.
