@@ -1,3 +1,4 @@
+{-# LANGUAGE CPP #-}
 {-# LANGUAGE OverloadedStrings #-}
 
 --------------------------------------------------------------------------------
@@ -5,12 +6,12 @@
 --------------------------------------------------------------------------------
 -- |
 --  Module      :  Utils
---  Copyright   :  (c) 2003, Graham Klyne, 2009 Vasili I Galchin, 2011, 2012, 2013, 2014 Douglas Burke
+--  Copyright   :  (c) 2003, Graham Klyne, 2009 Vasili I Galchin, 2011, 2012, 2013, 2014, 2018 Douglas Burke
 --  License     :  GPL V2
 --
 --  Maintainer  :  Douglas Burke
 --  Stability   :  experimental
---  Portability :  OverloadedStrings
+--  Portability :  CPP, OverloadedStrings
 --
 --  Support for the RDF Parsing modules.
 --
@@ -67,6 +68,11 @@ import Swish.RDF.Vocabulary
     )
 
 import Data.Char (isSpace, isHexDigit, chr)
+
+#if MIN_VERSION_base(4, 7, 0)
+import Data.Functor (($>))
+#endif
+
 import Data.Maybe (fromMaybe, fromJust)
 
 import Network.URI (URI(..), relativeTo, parseURIReference)
@@ -78,6 +84,11 @@ import qualified Data.Text      as T
 import qualified Data.Text.Lazy as L
 import qualified Data.Text.Read as R
 
+#if !MIN_VERSION_base(4, 7, 0)
+($>) :: Functor f => f a -> b -> f b
+($>) = flip (<$)
+#endif
+
 -- Code
 
 -- | Append the two URIs. Given the change in signature of
@@ -154,7 +165,7 @@ type ParseResult = Either String RDFGraph
 
 -- | Run the parser and ignore the result.
 ignore :: (Applicative f) => f a -> f ()
-ignore f = f *> pure ()
+ignore f = f $> ()
 
 -- | Match the character.
 char :: Char -> Parser s Char
@@ -216,7 +227,7 @@ manyTill ::
     -> Parser s [a]
 manyTill p end = go
   where
-    go = (end *> return [])
+    go = (end $> [])
          <|>
          ((:) <$> p <*> go)
 
@@ -265,7 +276,7 @@ simpleSpace = ignore $ many1Satisfy isSpace
 
 -- TODO: this should use eoln rather than a check on \n
 oneLineComment :: Parser s ()
-oneLineComment = ichar '#' *> manySatisfy (/= '\n') *> pure ()
+oneLineComment = (ichar '#' *> manySatisfy (/= '\n')) $> ()
 
 {-
 
@@ -344,7 +355,7 @@ hex8 = do
 --------------------------------------------------------------------------------
 --
 --  Copyright (c) 2003, Graham Klyne, 2009 Vasili I Galchin,
---    2011, 2012, 2014 Douglas Burke
+--    2011, 2012, 2014, 2018 Douglas Burke
 --  All rights reserved.
 --
 --  This file is part of Swish.
