@@ -1,14 +1,16 @@
+{-# LANGUAGE CPP #-}
+
 --------------------------------------------------------------------------------
 --  See end of this file for licence information.
 --------------------------------------------------------------------------------
 -- |
 --  Module      :  Query
---  Copyright   :  (c) 2003, Graham Klyne, 2009 Vasili I Galchin, 2011, 2012 Douglas Burke
+--  Copyright   :  (c) 2003, Graham Klyne, 2009 Vasili I Galchin, 2011, 2012, 2014 Douglas Burke
 --  License     :  GPL V2
 --
 --  Maintainer  :  Douglas Burke
 --  Stability   :  experimental
---  Portability :  H98
+--  Portability :  CPP
 --
 --  This module defines functions for querying an RDF graph to obtain
 --  a set of variable substitutions, and to apply a set of variable
@@ -19,18 +21,32 @@
 --  A minimal example is shown below, where we query a very simple
 --  graph:
 --
--- >>> :m + Swish.RDF Swish.RDF.Parser.N3 Swish.RDF.Query
 -- >>> :set -XOverloadedStrings
+-- >>> import Swish.RDF
+-- >>> import Swish.RDF.Parser.N3 (parseN3fromText)
+-- >>> import Swish.RDF.Query
+-- >>> import Swish.VarBinding (VarBinding(vbMap))
+-- >>> import Network.URI (parseURI)
+-- >>> import Data.Maybe (fromJust, mapMaybe)
 -- >>> let qparse = either error id . parseN3fromText
 -- >>> let igr = qparse "@prefix a: <http://example.com/>. a:a a a:A ; a:foo a:bar. a:b a a:B ; a:foo a:bar."
 -- >>> let qgr = qparse "?node a ?type."
--- >>> rdfQueryFind qgr igr
--- [[(?type,a:B),(?node,a:b)],[(?type,a:A),(?node,a:a)]]
--- >>> let bn = (toRDFLabel . Data.Maybe.fromJust . Network.URI.parseURI) "http://example.com/B"
--- >>> rdfFindArcs (rdfObjEq bn) igr
+-- >>> let ans = rdfQueryFind qgr igr
+-- >>> :t ans
+-- ans :: [Swish.RDF.VarBinding.RDFVarBinding]
+-- >>> ans
+-- [[(?node,a:a),(?type,a:A)],[(?node,a:b),(?type,a:B)]]
+-- >>> let bn = toRDFLabel . fromJust . parseURI $ "http://example.com/B"
+-- >>> let arcs = rdfFindArcs (rdfObjEq bn) igr
+-- >>> :t arcs
+-- arcs :: [RDFTriple]
+-- >>> arcs
 -- [(a:b,rdf:type,a:B)]
--- >>> Data.Maybe.mapMaybe (flip Swish.RDF.VarBinding.vbMap (Var "type")) $ rdfQueryFind qgr igr
--- [a:B,a:A]
+-- >>> let lbls = mapMaybe (`vbMap` (Var "type")) ans
+-- >>> :t lbls
+-- lbls :: [RDFLabel]
+-- >>> lbls
+-- [a:A,a:B]
 -- 
 --------------------------------------------------------------------------------
 
@@ -83,7 +99,10 @@ import Control.Monad (when)
 import Control.Monad.State (State, runState, modify)
 
 import Data.Maybe (mapMaybe, isJust, fromJust)
+
+#if (!defined(__GLASGOW_HASKELL__)) || (__GLASGOW_HASKELL__ < 710)
 import Data.Monoid (Monoid(..))
+#endif
 
 import qualified Data.Set as S
 
