@@ -9,7 +9,7 @@
 -- |
 --  Module      :  VarBinding
 --  Copyright   :  (c) 2003, Graham Klyne, 2009 Vasili I Galchin, 
---                 2011, 2012, 2014, 2015, 2016 Douglas Burke
+--                 2011, 2012, 2014, 2015, 2016, 2018 Douglas Burke
 --  License     :  GPL V2
 --
 --  Maintainer  :  Douglas Burke
@@ -54,6 +54,10 @@ import Control.Applicative ((<$>), (<*>))
 import Data.Monoid (Monoid(..), mconcat)
 #endif
 
+#if !(MIN_VERSION_base(4, 11, 0))
+import Data.Semigroup
+#endif
+
 import Control.Monad (mplus)
 
 import Data.Function (on)
@@ -92,9 +96,14 @@ instance (Ord a, Ord b) => Ord (VarBinding a b) where
 
 -- | When combining instances, if there is an overlapping binding then
 --   the  value from the first instance is used.
+instance (Ord a, Ord b) => Semigroup (VarBinding a b) where
+    (<>) = joinVarBindings
+    
 instance (Ord a, Ord b) => Monoid (VarBinding a b) where
     mempty = nullVarBinding
-    mappend = joinVarBindings
+#if !(MIN_VERSION_base(4, 11, 0))
+    mappend = (<>)
+#endif
 
 -- | The Show instance only displays the pairs of variables
 --    in the binding.
@@ -102,7 +111,7 @@ instance (Ord a, Ord b) => Monoid (VarBinding a b) where
 instance (Show a, Show b) => Show (VarBinding a b) where
     show = show . S.toList . vbEnum
 
--- | The null, or empry, binding maps no query variables.
+-- | The null, or empty, binding maps no query variables.
 --   This is the 'mempty' instance of the Monoid.
 --
 nullVarBinding :: VarBinding a b
@@ -114,8 +123,10 @@ nullVarBinding = VarBinding
 
 -- |Return a list of the variables bound by a supplied variable binding
 --
+-- The Ord instance on b is not needed (it was circa GHC 7.6) but is
+-- kept in to avoid the need to increase the minor version number.
 boundVars :: (Ord a, Ord b) => VarBinding a b -> S.Set a
-boundVars = S.map fst . vbEnum  -- Ord b is needed got GHC 7.6
+boundVars = S.map fst . vbEnum
 
 -- |VarBinding subset function, tests to see if one query binding
 --  is a subset of another;  i.e. every query variable mapping defined
