@@ -6,7 +6,7 @@
 --------------------------------------------------------------------------------
 -- |
 --  Module      :  RDFQueryTest
---  Copyright   :  (c) 2003, Graham Klyne, 2009 Vasili I Galchin, 2011, 2012, 2013, 2014 Douglas Burke
+--  Copyright   :  (c) 2003, Graham Klyne, 2009 Vasili I Galchin, 2011, 2012, 2013, 2014, 2018 Douglas Burke
 --  License     :  GPL V2
 --
 --  Maintainer  :  Douglas Burke
@@ -1051,24 +1051,24 @@ test4 =
   [ test "testQuery41" (not $ null var41)
   , testEq "testQuery41a" 1 (length var41)
   , testEq "testResult41" 1 (length res41)
-  , testGr "testResult41a" result41a (fst $ unzip $ head res41)
+  , testGr "testResult41a" result41a (map fst (head res41))
   , testEqv "testUnbound41a" [] (snd $ head $ head res41)
   , test "testQuery42" (not $ null var42)
   , testEq "testQuery42a" 1 (length var42)
   , testEq "testResult42" 1 (length res42)
-  , testGr "testResult42a" result42a (fst $ unzip $ head res42)
+  , testGr "testResult42a" result42a (map fst (head res42))
   , testEqv "testUnbound42a" [Var "b"] (snd $ head $ head res42)
   , test "testQuery43" (not $ null var43)
   , testEq "testQuery43a" 1 (length var43)
   , testEq "testResult43" 1 (length res43)
-  , testGr "testResult43a" result43a (fst $ unzip $ head res43)
+  , testGr "testResult43a" result43a (map fst (head res43))
   , testEqv "testUnbound43a" [Var "a"] (snd $ head $ head res43)
   , test "testQuery44" (not $ null var44)
   , testEq "testQuery44a"   2 (length var44)
   , testEq "testResult44"   2 (length res44)
-  , testGr "testResult44a"  result44a  (fst $ unzip res44_2)
+  , testGr "testResult44a"  result44a  (map fst res44_2)
   , testEqv "testUnbound44a" unbound44a (snd $ head res44_2)
-  , testGr "testResult44b"  result44b  (fst $ unzip res44_1)
+  , testGr "testResult44b"  result44b  (map fst res44_1)
   , testEqv "testUnbound44b" unbound44b (snd $ head res44_1)
   , test "testQuery45" (not $ null var45)
   , testEq "testQuery45a"   1 (length var45)
